export class StbCollapse {
    constructor() {
        this.active = false;
        this.activeClass = 'show';
        this.accordion = false;
    }
    componentDidLoad() {
        this.getCollapseElements();
        this.addClickListener();
        this.checkForActiveElement();
    }
    getCollapseElements() {
        this.collapseElements = this.element.querySelectorAll('[data-toggle="collapse"]');
    }
    addClickListener() {
        this.collapseElements.forEach((collapse) => {
            collapse.classList.add('coll-div');
            const collapsible = this.getCollapsible(collapse);
            this.addCollapsibleClass(collapsible);
            collapse.addEventListener("click", () => {
                if (collapsible.classList.contains('show')) {
                    this.hideCollapsible(collapse);
                }
                else {
                    this.showCollapsible(collapse);
                }
            });
        });
    }
    checkForActiveElement() {
        this.activeDiv = document.querySelector('.show');
        if (this.activeDiv) {
            this.activeDiv.style.height = this.activeDiv.children[0].offsetHeight + 'px';
        }
    }
    addCollapsibleClass(element) {
        element.classList.add('collapsing');
    }
    getCollapsible(element) {
        // if (element.classList.contains('stb-item-disabled')) return null;
        let target;
        if (element.getAttribute('data-target'))
            target = element.getAttribute('data-target');
        if (element.getAttribute('href'))
            target = element.getAttribute('href');
        return document.querySelector(target);
    }
    showCollapsible(element) {
        const collapsible = this.getCollapsible(element);
        if (!collapsible) {
            return;
        }
        if (this.accordion && this.activeDiv && this.activeDiv !== collapsible) {
            this.activeDiv.style.height = 0;
            setTimeout(() => {
                this.activeDiv.classList.remove('show');
                this.activeDiv = collapsible;
            }, 500);
        }
        collapsible.classList.add('show');
        setTimeout(() => {
            collapsible.style.height = collapsible.children[0].offsetHeight + 'px';
        }, 50);
    }
    hideCollapsible(element) {
        const collapsible = this.getCollapsible(element);
        collapsible.style.height = 0;
        setTimeout(() => {
            collapsible.classList.remove(this.activeClass);
        }, 500);
    }
    show(element) {
        this.showCollapsible(element);
        this.showEvent.emit({
            element: element
        });
    }
    hide(element) {
        this.showCollapsible(element);
        this.hideEvent.emit({
            element: element
        });
    }
    componentDidUnload() {
    }
    static get is() { return "stb-collapse"; }
    static get properties() { return { "accordion": { "type": Boolean, "attr": "accordion" }, "active": { "type": Boolean, "attr": "active" }, "activeClass": { "type": String, "attr": "active-class" }, "element": { "elementRef": true }, "hide": { "method": true }, "show": { "method": true } }; }
    static get events() { return [{ "name": "showEvent", "method": "showEvent", "bubbles": true, "cancelable": true, "composed": true }, { "name": "hideEvent", "method": "hideEvent", "bubbles": true, "cancelable": true, "composed": true }]; }
    static get style() { return "/**style-placeholder:stb-collapse:**/"; }
}
